@@ -3,8 +3,8 @@
 #' Backend function called by logout(). Sends a logout call and disables your oauth2 token.
 #'
 #' @param RH object of class RobinHood
-#' @import curl magrittr
-#' @export
+#' @import httr magrittr
+
 api_logout <- function(RH) {
 
   detail <- paste("client_id=",
@@ -13,10 +13,12 @@ api_logout <- function(RH) {
                   RH$tokens.refresh_token,
                   sep = "")
 
-  logout <- new_handle() %>%
-    handle_setopt(copypostfields = detail) %>%
-    handle_setheaders("Accept" = "application/json") %>%
-    curl_fetch_memory(url = api_endpoints("revoke_token"))
+  # URL
+  url <- paste(api_endpoints("revoke_token"), detail, sep = "")
+
+  # POST call
+  dta <- POST(url) %>%
+    content(type = "json")
 
   logout <- logout$content
 }
